@@ -668,7 +668,7 @@ start_client (Client* client)
   if (client->id || client->match_rule == MATCH_PROP)
     {
       APPEND (pending_list, client);
-      if (purge_delay)
+      if (purge_delay > 0)
 	{
 	  g_assert (client->purge_timeout_id == 0);
 	  client->purge_timeout_id = gtk_timeout_add (purge_delay, purge, client);
@@ -1164,10 +1164,10 @@ print_client (Client *client)
 {
   GSList *l;
 
-  printf ("  id: %s\n", client->id);
-  printf ("  handle: %s\n", client->handle);
-  printf ("  connection: %p\n", client->connection);
-  printf ("  properties:\n");
+  gsm_verbose ("  id: %s\n", client->id);
+  gsm_verbose ("  handle: %s\n", client->handle);
+  gsm_verbose ("  connection: %p\n", client->connection);
+  gsm_verbose ("  properties:\n");
 
   for (l = client->properties; l; l = l->next)
     {
@@ -1175,22 +1175,22 @@ print_client (Client *client)
       int v;
 
       p = l->data;
-      printf ("    ((name \"%s\") (type \"%s\")", p->name, p->type);
+      gsm_verbose ("    ((name \"%s\") (type \"%s\")", p->name, p->type);
       for (v = 0; v < p->num_vals; v++)
 	{
 	  int i;
 	  guchar *c;
 
-	  printf (" (value \"");
+	  gsm_verbose (" (value \"");
 	  c = (guchar *) p->vals[v].value;
 	  for (i = 0; i < p->vals[v].length; i++)
 	    if (c[i] < 0x80)
-	      printf ("%c", (int) c[i]);
+	      gsm_verbose ("%c", (int) c[i]);
 	    else
-	      printf ("\\x%02x", (int) c[i]);
+	      gsm_verbose ("\\x%02x", (int) c[i]);
 
-	  printf ("\")");
-	} printf (")\n");
+	  gsm_verbose ("\")");
+	} gsm_verbose (")\n");
     }
 }
 
@@ -1274,7 +1274,7 @@ process_save_request (Client* client, int save_type, gboolean shutdown,
       gint delay = client->handle ? warn_delay : purge_delay;
       save_state = SAVE_PHASE_1;
       save_state_changed ();
-      if (delay)
+      if (delay > 0)
 	{
 	  g_assert (warn_timeout_id == -1);
 	  warn_timeout_id = gtk_timeout_add (delay, no_response_warning, NULL);
@@ -1405,7 +1405,7 @@ update_save_state (void)
 	      gtk_timeout_remove (warn_timeout_id);
 	      warn_timeout_id = -1;
 	    }
-	  if (warn_delay)
+	  if (warn_delay > 0)
 	    {
 	      g_assert (warn_timeout_id == -1);
 	      warn_timeout_id = gtk_timeout_add (warn_delay, 
@@ -1462,7 +1462,7 @@ update_save_state (void)
 	  run_shutdown_commands (zombie_list);
 	  run_shutdown_commands (live_list);
 
-	  if (suicide_delay)
+	  if (suicide_delay > 0)
 	    {
 	      g_assert (warn_timeout_id == -1);
 	      warn_timeout_id = gtk_timeout_add (suicide_delay, 
